
clear all ;% clear all variables
close all
%============== Define global variables ===================================================
global BitRate Bits SampleRate samplesperbit  DataLength t_range f_sym Ref_Frequency

BitRate = 10e9;  
Bits = 16;
TimeWindow = Bits/BitRate;
SampleRate = BitRate*2^5;
DataLength = TimeWindow*SampleRate;
Ref_Frequency = 193.1e12; %[Hz] Physical reference optical frequency
samplesperbit = SampleRate/BitRate; % data number per bit

% time, frequency(baseband) range
t_range = 0:1/SampleRate:1/SampleRate*(DataLength-1);
f_sym = SampleRate*(-DataLength/2:(DataLength/2-1))/DataLength; %

%=========== Define a Gaussian Pulse ==========================================================
Pk1 = 10e-3; %[W] PeakPower
Pk2 = 100e-3; %[W] PeakPower
t_FWHM = 1/(3*BitRate); %[sec] Pulse Full Width at Half Maximum
t_w = t_FWHM/(2*sqrt(log(2))); %[sec] Half-width at 1/e

A_in1 = sqrt(Pk1)*exp(-0.5*((t_range-0.5*max(t_range))/t_w).^2);
A_in2 = sqrt(Pk2)*exp(-0.5*((t_range-0.5*max(t_range))/t_w).^2);

%--------------------------------------------------------------------------
%---------------- Transmission -------------------------------------
z = [10 50 100]*1e3; % [m]

%=========== Fiber Parameters +++++++++++++++++========
%  FiberAttenuation = 0.2e-3; %[dB/m]
%  Dispersion = 16e-6;   %[s/m^2]
%  DispersionSlope = 0.08e3;   %[s/m^3]
%  NonlinearIndex = 2.6e-20; %[m^2/W]
%  CoreArea = 80e-12; %[m^2]
%
%=== Simulation Parameters =====
%  MaxPhaseChange = 0.005; %[rad] Maxi

for k=1:length(z)
    
[ya_t(k,:),ya_f(k,:)] = SingleModeFiber(A_in1,z(k),0,0,0,2.6e-20,80e-12,0.005);
[yb_t(k,:),yb_f(k,:)] = SingleModeFiber(A_in2,z(k),0,0,0,2.6e-20,80e-12,0.005);
[yc_t(k,:),yc_f(k,:)] = SingleModeFiber(A_in1,z(k),0,16e-6,0,2.6e-20,80e-12,0.005);

end

figure(1)
% Po=10mW,     
subplot 211
plot(t_range,abs(ya_t(1,:)).^2,'b',t_range,abs(ya_t(2,:)).^2,'g',t_range,abs(ya_t(3,:)).^2,'r')
subplot 212
plot(f_sym,abs(fftshift(ya_f(1,:))/SampleRate).^2,'b',f_sym,abs(fftshift(ya_f(2,:))/SampleRate).^2,'g',f_sym,abs(fftshift(ya_f(3,:))/SampleRate).^2,'r')

figure(2)
% Po=100mW,    
subplot 211
plot(t_range,abs(yb_t(1,:)).^2,'b',t_range,abs(yb_t(2,:)).^2,'g',t_range,abs(yb_t(3,:)).^2,'r')
subplot 212
plot(f_sym,abs(fftshift(yb_f(1,:))/SampleRate).^2,'b',f_sym,abs(fftshift(yb_f(2,:))/SampleRate).^2,'g',f_sym,abs(fftshift(yb_f(3,:))/SampleRate).^2,'r')

figure(3)
% Po=10mW,   лƯ Բ  
subplot 211
plot(t_range,abs(yc_t(1,:)).^2,'b',t_range,abs(yc_t(2,:)).^2,'g',t_range,abs(yc_t(3,:)).^2,'r')
subplot 212
plot(f_sym,abs(fftshift(yc_f(1,:))/SampleRate).^2,'b',f_sym,abs(fftshift(yc_f(2,:))/SampleRate).^2,'g',f_sym,abs(fftshift(yc_f(3,:))/SampleRate).^2,'r')

% Check the pulse energy in time domain and in frequency domain
% Ex) 
% E_t = dt*sum(abs(yc_t(1,:)).^2); % dt = t_range(2)-t_range(1)
% E_f = df*sum(abs(fftshift(yc_f(1,:))/SampleRate).^2);  % df = f_sym(2)-f_sym(1)
%
% E_t should be equal to E_f.







