%Fig 8-23
clear all ;% clear all variables
close all

%============== Define global variables ===================================================
global SampleRate DataLength Ref_Frequency

BitRate = 1e9;  
Bits2Power = 8;
Bits = 2^Bits2Power;
TimeWindow = Bits/BitRate;
SampleRate = BitRate*2^10;
DataLength = TimeWindow*SampleRate;
Ref_Frequency = 193.1e12; %[Hz] Reference optical frequency


%----------- Input: Laser ------------------------
UnmodulatedPowerdBm = -10:.5:10;
UnmodulatedPower = 1e-3*10.^(UnmodulatedPowerdBm/10); % [dBm]->[W] Unit change 

k = length(UnmodulatedPower);

%------------ EDFA Models ------------------------
IncludeNoise = 'Yes';
NFdB = 5; %[dB]

G_Target = 20; %[dB] used for EDFA_gain
Pout_Target = 20; %[dBm] used for EDFA_power
Unsat_GaindB = 20; %[dB] used for EDFA_saturation
Sat_OutputdBm = 20; %[dBm] used for EDFA_saturation

for n=1:k
    
Laser1(n,:) = LaserCW(UnmodulatedPower(n));
EDFA_out1(n,:) = EDFA_gain(Laser1(n,:),G_Target,IncludeNoise,NFdB);
P_out1(n) = PowerMeterdBm(EDFA_out1(n,:));

EDFA_out2(n,:) = EDFA_power(Laser1(n,:),Pout_Target,IncludeNoise,NFdB);
P_out2(n) = PowerMeterdBm(EDFA_out2(n,:));

EDFA_out3(n,:) = EDFA_saturation(Laser1(n,:),Unsat_GaindB,Sat_OutputdBm,IncludeNoise,NFdB);
P_out3(n) = PowerMeterdBm(EDFA_out3(n,:));
end

GEDFA_gain = P_out1-UnmodulatedPowerdBm;
GEDFA_power = P_out2-UnmodulatedPowerdBm;
GEDFA_sat = P_out3-UnmodulatedPowerdBm;

figure(1)
subplot 211
plot(UnmodulatedPowerdBm,P_out1,UnmodulatedPowerdBm,P_out2,'r',UnmodulatedPowerdBm,P_out3,'k'),
xlabel('P_i_n[dBm]'), ylabel('P_o_u_t[dBm]')
legend('Gain Mode','Power Mode','Saturation Mode')

subplot 212
plot(UnmodulatedPowerdBm,GEDFA_gain,UnmodulatedPowerdBm,GEDFA_power,'r',UnmodulatedPowerdBm,GEDFA_sat,'k'),
xlabel('P_i_n[dBm]'), ylabel('Gain[dB]')
legend('Gain Mode','Power Mode','Saturation Mode')


