% gaussian_prop1.m
% Fig 8-5
%
clear all ;% clear all variables
close all
%============== Define global variables ===================================================
global BitRate Bits SampleRate samplesperbit  DataLength f_sym Ref_Frequency

BitRate = 2.5e9;  
Bits = 16;
TimeWindow = Bits/BitRate;
SampleRate = BitRate*2^10;
DataLength = TimeWindow*SampleRate;
Ref_Frequency = 193.1e12; %[Hz] Physical reference optical frequency
samplesperbit = SampleRate/BitRate; % data number per bit

% time, frequency(baseband) range
t_range = 0:1/SampleRate:1/SampleRate*(DataLength-1);
f_sym = SampleRate*(-DataLength/2:(DataLength/2-1))/DataLength; %

%=========== Define a Gaussian Pulse ==========================================================
Pk = 10e-3; %[W] PeakPower
t_FWHM = 1/(3*BitRate); %[sec] Pulse Full Width at Half Maximum
t_w = t_FWHM/(2*sqrt(log(2))); %[sec] Half-width at 1/e

A_in = sqrt(Pk)*exp(-0.5*((t_range-0.5*max(t_range))/t_w).^2);
%--------------------------------------------------------------------------

%=========== Fiber Parameters +++++++++++++++++========
S_Fiber_Length = 50e3; %[m] Fiber length for one iteration
S_FiberAttenuation =  0.2e-3; %[dB/m]
S_Dispersion = 16e-6;   %[s/m^2]
S_DispersionSlope = 0.08e3;   %[s/m^3]
S_NonlinearIndex = 0; %[m^2/W]   % Fiber Nonlinearity is ignored.
S_CoreArea = 80e-12; %[m^2]
S_MaxPhaseChange = 0.005; %[rad]
%--------------------------------------------------------------------------

SMF_out(1,:) = A_in;
yf1(1,:) = fftshift(fft(A_in));


for k = 1:4;
     
     [SMF_out(k+1,:) yf1(k+1,:)] = SingleModeFiber(SMF_out(k,:),S_Fiber_Length,S_FiberAttenuation,S_Dispersion,S_DispersionSlope,S_NonlinearIndex,S_CoreArea,S_MaxPhaseChange);
    
end


zz=0:S_Fiber_Length:(k*S_Fiber_Length);
ZZ = zz'*ones(1,length(t_range));

figure(1)
plot3(ZZ(1,:),t_range,abs(SMF_out(1,:)), ZZ(2,:),t_range,abs(SMF_out(2,:)),ZZ(3,:),...
    t_range,abs(SMF_out(3,:)),ZZ(4,:),t_range,abs(SMF_out(4,:)),ZZ(5,:),t_range,abs(SMF_out(5,:)))
xlabel('z [m]'),ylabel('t [sec]')
title('Gaussian pulse transmission when the fiber nonlinearity is ignored.(R_b=2.5Gb/s)')
grid on

% now assume that the fiber loss is zero

S_FiberAttenuation =  0; %[dB/m]   % Fiber loss is ignored.

for k = 1:4;
     
     [SMF_out(k+1,:) yf1(k+1,:)] = SingleModeFiber(SMF_out(k,:),S_Fiber_Length,S_FiberAttenuation,S_Dispersion,S_DispersionSlope,S_NonlinearIndex,S_CoreArea,S_MaxPhaseChange);
    
end


figure(2)
plot3(ZZ(1,:),t_range,abs(SMF_out(1,:)), ZZ(2,:),t_range,abs(SMF_out(2,:)),ZZ(3,:),...
    t_range,abs(SMF_out(3,:)),ZZ(4,:),t_range,abs(SMF_out(4,:)),ZZ(5,:),t_range,abs(SMF_out(5,:)))
xlabel('z [m]'),ylabel('t [sec]')
title('Gaussian pulse transmission with dispersion alone.(R_b=2.5Gb/s)')

grid on
